==> trilinos_10.0.4.dfsg.orig.tar.gz: trilinos-10.0.4.dfsg.orig/packages/Sundance/src-solvers/LinearSolvers/Thyra_LOWSFactoryBuilder.hpp <==
/*@HEADER
// ***********************************************************************
// 
//       Ifpack: Object-Oriented Algebraic Preconditioner Package
//                 Copyright (2002) Sandia Corporation
// 
// Under terms of Contract DE-AC04-94AL85000, there is a non-exclusive
// license for use of this work by or on behalf of the U.S. Government.
// 
// This library is free software; you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as
// published by the Free Software Foundation; either version 2.1 of the
// License, or (at your option) any later version.
//  
// This library is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//  
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
// USA
// Questions? Contact Michael A. Heroux (maherou@sandia.gov) 
// 
// ***********************************************************************
//@HEADER
*/

#ifndef THYRA_LOWSFACTORYBUILDER_HPP
#define THYRA_LOWSFACTORYBUILDER_HPP

#include "SundanceDefs.hpp"

#ifndef TRILINOS_6
#include "Thyra_LinearOpWithSolveFactoryBase.hpp"
#include "Teuchos_ParameterList.hpp"


namespace Thyra 
{
  using Teuchos::ParameterList;
  using Teuchos::RefCountPtr;

  /** 
   * Provides a static method that creates a LOWSFactor given a parameter list
   */
  class LOWSFactoryBuilder
  {
  public:
    /** */
    static RefCountPtr<LinearOpWithSolveFactoryBase<double> >
    createLOWSFactory(const ParameterList& params);
  };
}  

#endif

#endif // THYRA_LOWSFACTORYBUILDER_HPP

==> trilinos_10.4.0.dfsg.orig.tar.gz: trilinos-10.4.0.dfsg.orig/packages/Sundance/src-solvers/LinearSolvers/Thyra_LOWSFactoryBuilder.hpp <==
/*@HEADER
// ***********************************************************************
// 
//       Ifpack: Object-Oriented Algebraic Preconditioner Package
//                 Copyright (2002) Sandia Corporation
// 
// Under terms of Contract DE-AC04-94AL85000, there is a non-exclusive
// license for use of this work by or on behalf of the U.S. Government.
// 
// This library is free software; you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as
// published by the Free Software Foundation; either version 2.1 of the
// License, or (at your option) any later version.
//  
// This library is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//  
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
// USA
// Questions? Contact Michael A. Heroux (maherou@sandia.gov) 
// 
// ***********************************************************************
//@HEADER
*/

#ifndef THYRA_LOWSFACTORYBUILDER_HPP
#define THYRA_LOWSFACTORYBUILDER_HPP

#include "SundanceDefs.hpp"

#ifndef TRILINOS_6
#include "Thyra_LinearOpWithSolveFactoryBase.hpp"
#include "Teuchos_ParameterList.hpp"


namespace Thyra 
{
  using Teuchos::ParameterList;
  using Teuchos::RefCountPtr;

  /** 
   * Provides a static method that creates a LOWSFactor given a parameter list
   */
  class LOWSFactoryBuilder
  {
  public:
    /** */
    static RCP<LinearOpWithSolveFactoryBase<double> >
    createLOWSFactory(const ParameterList& params);
  };
}  

#endif

#endif // THYRA_LOWSFACTORYBUILDER_HPP
